@@ -15,16 +15,16 @@ import (
 	"net/url"
 	"time"
 
-	"github.com/lucas-clemente/quic-go"
+	"github.com/quic-go/quic-go"
+
+	"github.com/syncthing/syncthing/lib/osutil"
 )
 
-var (
-	quicConfig = &quic.Config{
-		ConnectionIDLength: 4,
-		MaxIdleTimeout:     30 * time.Second,
-		KeepAlivePeriod:    15 * time.Second,
-	}
-)
+var quicConfig = &quic.Config{
+	ConnectionIDLength: 4,
+	MaxIdleTimeout:     30 * time.Second,
+	KeepAlivePeriod:    15 * time.Second,
+}
 
 func quicNetwork(uri *url.URL) string {
 	switch uri.Scheme {
@@ -65,9 +65,7 @@ func (q *quicTlsConn) ConnectionState() tls.ConnectionState {
 }
 
 func packetConnUnspecified(conn interface{}) bool {
-	// Since QUIC connections are wrapped, we can't do a simple typecheck
-	// on *net.UDPAddr here.
 	addr := conn.(net.PacketConn).LocalAddr()
-	host, _, err := net.SplitHostPort(addr.String())
-	return err == nil && net.ParseIP(host).IsUnspecified()
+	ip, err := osutil.IPFromAddr(addr)
+	return err == nil && ip.IsUnspecified()
 }
